@@ -11,20 +11,19 @@ from plumber import (
     finalize,
     Part,
 )
-from zope.interface import implements
+from zope.interface import implementer
 from node.base import AttributedNode
 from node.locking import locktree
-from node.aliasing import (
-    AliasedNodespace,
-    DictAliaser,
-)
+from node.parts.alias import DictAliaser
 from node.parts import (
+    Alias,
     NodeChildValidate,
     Nodespaces,
     Adopt,
     Attributes,
     DefaultInit,
     Nodify,
+    Storage,
     OdictStorage,
 )
 from node.utils import debug
@@ -98,16 +97,16 @@ class PrincipalsConfig(object):
         #self.member_relation = member_relation
 
 
+@implementer(IUsersConfig)
 class UsersConfig(PrincipalsConfig):
     """Define how users look and where they are.
     """
-    implements(IUsersConfig)
 
 
+@implementer(IGroupsConfig)
 class GroupsConfig(PrincipalsConfig):
     """Define how groups look and where they are.
     """
-    implements(IGroupsConfig)
 
 
 class RolesConfig(PrincipalsConfig):
@@ -117,13 +116,40 @@ class RolesConfig(PrincipalsConfig):
     """
 
 
-class PrincipalAliasedAttributes(AliasedNodespace):
-    
+class PrincipalAliasedAttributes(object):
+    __metaclass__ = plumber
+    __plumbing__ = (
+        Alias,
+        NodeChildValidate,
+        Adopt,
+        Nodify,
+        Storage,
+    )
     allow_non_node_childs = True
     
+    def __init__(self, context, aliaser=None):
+        """
+        context
+            the node whose children to alias
+            
+        aliaser
+            the aliaser to be used
+        """
+        self.__name__ = context.name
+        self.__parent__ = None
+        self.context = context
+        self.aliaser = aliaser
+    
+    @property
+    def storage(self):
+        return self.context
+    
     @property
     def changed(self):
         return self.context.changed
+    
+    def __repr__(self):
+        return "Aliased " + self.context.__repr__()
 
 
 class AliasedPrincipal(Part):
@@ -405,8 +431,8 @@ class LDAPPrincipals(OdictStorage):
         
         context._load_keys()
         
-        self.expiresAttr = cfg.expiresAttr
-        self.expiresUnit = cfg.expiresUnit
+        self.expiresAttr = getattr(cfg, 'expiresAttr', None)
+        self.expiresUnit = getattr(cfg, 'expiresUnit', None)
         self.principal_attrmap = cfg.attrmap
         self.principal_attraliaser = DictAliaser(cfg.attrmap, cfg.strict)
         self.context = context
@@ -570,18 +596,26 @@ class LDAPPrincipals(OdictStorage):
 
     @default
     def search(self, criteria=None, attrlist=None,
-               exact_match=False, or_search=False):
+               exact_match=False, or_search=False, or_keys=None, or_values=None,
+               page_size=None, cookie=None):
         results = self.context.search(
             criteria=self._unalias_dict(criteria),
             attrlist=self._unalias_list(attrlist),
             exact_match=exact_match,
-            or_search=or_search)
-        if attrlist is None:
-            return results
-        aliased_results = \
-            [(uid, self._alias_dict(attrs)) for uid, attrs in results]
-        return aliased_results
-    
+            or_search=or_search,
+            or_keys=or_keys,
+            or_values=or_values,
+            page_size=page_size,
+            cookie=cookie
+            )
+        if type(results) is tuple:
+            results, cookie = results
+        if attrlist is not None:
+            results = [(uid, self._alias_dict(attrs)) for uid, attrs in results]
+        if cookie is not None:
+            return results, cookie
+        return results
+ 
     @default
     @locktree
     def create(self, pid, **kw):
@@ -1069,4 +1103,4 @@ class Ugm(object):
         DefaultInit,
         Nodify,
         OdictStorage,
-    )
\ No newline at end of file
+    )
